xhttp

package
v0.1.0-alpha.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 25, 2025 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CompletionDTO

type CompletionDTO struct {
	Model      string               `json:"model" required:"true" doc:"Model identifier as defined in rook.yaml"`
	Messages   []*rookllmv1.Message `json:"messages" minItems:"1" doc:"Conversation messages in chronological order"`
	Parameters map[string]any       `json:"parameters,omitempty" doc:"Backend-specific parameters"`
}

CompletionDTO is the DTO for the complete operation.

type CompletionInput

type CompletionInput struct {
	Body CompletionDTO
}

CompletionInput is the huma input for the Complete operation.

type CompletionOutput

type CompletionOutput struct {
	Body *rookllmv1.CompletionResponse
}

CompletionOutput is the huma output for the Complete operation.

type CompletionStreamInput

type CompletionStreamInput struct {
	Body CompletionDTO
}

CompletionStreamInput is the huma input for the CompleteStream operation.

type LLMHandler

type LLMHandler struct {
	// contains filtered or unexported fields
}

LLMHandler handles HTTP requests for LLM.

func NewLLMHandler

func NewLLMHandler(api huma.API, backends *backend.Registry, models *model.Registry) *LLMHandler

NewLLMHandler creates a new LLMHandler instance.

type STTHandler

type STTHandler struct {
	// contains filtered or unexported fields
}

STTHandler handles HTTP requests for STT.

func NewSTTHandler

func NewSTTHandler(api huma.API, backends *backend.Registry, models *model.Registry) *STTHandler

NewSTTHandler creates a new STTHandler instance.

type SynthesisDTO

type SynthesisDTO struct {
	Model      string         `json:"model" required:"true" doc:"Model identifier as defined in rook.yaml"`
	Text       string         `json:"text" required:"true" doc:"Text to synthesize"`
	Parameters map[string]any `json:"parameters,omitempty" doc:"Backend-specific parameters"`
}

SynthesisDTO is the DTO for the complete operation.

type SynthesisInput

type SynthesisInput struct {
	Body SynthesisDTO
}

SynthesisInput is the huma input for the Synthesis operation.

type TTSHandler

type TTSHandler struct {
	// contains filtered or unexported fields
}

TTSHandler handles HTTP requests for TTS.

func NewTTSHandler

func NewTTSHandler(api huma.API, backends *backend.Registry, models *model.Registry) *TTSHandler

NewTTSHandler creates a new TTSHandler instance.

type TranscriptionDTO

type TranscriptionDTO struct {
	AudioFile  huma.FormFile `form:"file" required:"true" contentType:"audio/*,application/octet-stream" doc:"Audio file to transcribe"`
	Model      string        `form:"model" required:"true" doc:"Model identifier as defined in rook.yaml"`
	Parameters string        `form:"parameters" doc:"Backend-specific parameters as JSON string"`
}

TranscriptionDTO represents the multipart form fields.

type TranscriptionInput

type TranscriptionInput struct {
	RawBody huma.MultipartFormFiles[TranscriptionDTO]
}

TranscriptionInput is the huma input for the Transcription operation.

type TranscriptionOutput

type TranscriptionOutput struct {
	Body *rooksttv1.TranscriptionResponse
}

TranscriptionOutput is the huma output for the Transcription operation.

Jump to